@@ -26,10 +26,25 @@ class MCDA:
         self.df_weighted = 0
         self.df_decision = []
 
-    def dataframe(self, alt_data, alt_labels=[], criteria_label=[]):
+    def dataframe(self, alt_data, alt_labels=[], criteria_labels=[]):
+        """
+        Set data for MCDM problem and save it into attribute: df_original.
+        
+        :param alt_data: They are the values of each criteria (columns) for each alternative (rows),
+        :type alt_data: list of list
+        
+        :param alt_labels: (Optional) Requires a list of labels for alternatives. If not provided, labels are automatically defined,
+        :type alt_labels: list
+        
+        :param criteria_labels: (Optional) Requires a list of labels for criteria. If not provided, labels are automatically defined. Its very important that order of criteria are from less to more important due to some algorithms requirements for weights definition.
+        :type criteria_labels: list
+        
+        :returns: no value
+        :rtype: none
+        """
 
         # define state labels if not exists
-        if criteria_label == []:
+        if criteria_labels == []:
             for s in range(0, len(alt_data[0])):
                 state_label.append("C" + str(s+1))
 
@@ -38,7 +53,7 @@ class MCDA:
             for a in range(0, len(alt_data)):
                 alt_labels.append("A" + str(a+1))
 
-        df_data = pd.DataFrame(data=alt_data, columns=criteria_label)
+        df_data = pd.DataFrame(data=alt_data, columns=criteria_labels)
         df_data.insert(loc=0,
                     column='alternatives',
                     value=alt_labels)
@@ -48,16 +63,32 @@ class MCDA:
         self.df_calc = copy.copy(dfo)
         self.decision = []
 
-    def set_weights_manually(self, weights):
-        if self.__check_weights(weights) is True:
+    def set_weights_manually(self, weights, free=False):
+        """
+        Set data weights manually for MCDM problems and save it into attribute: weights.
+        
+        :param weights: The numeric values of weights for each criteria (columns),
+        :type weights: list
+        
+        :param free: (default=False) If False, checks if weight value is a float between 0 and 1 and the sum is 100%,
+        :type free: boolean
+        
+        :returns: no value
+        :rtype: none
+        """
+        if self.__check_weights(weights, free) is True:
             self.weights = weights
         else:
             raise ValueError("Invalid weights! Each weight must be float between 0 and 1 and same number of criteria")
 
     def set_weights_by_ranking_A(self):
         """
+        Set weights for MCDM problems and save it into attribute: weights.
         The criteria must be ordered by importance c1 > c2 > c3 ... 
         Wj = {1 / rj} / {∑[1 / rk], where k range is 1 to n}
+
+        :returns: no value
+        :rtype: none
         """
         n = len(self.df_original.columns) - 1
         r = np.arange(1, n+1, 1).tolist()
@@ -72,8 +103,12 @@ class MCDA:
 
     def set_weights_by_ranking_B(self):
         """
+        Set weights for MCDM problems and save it into attribute: weights.
         The criteria must be ordered by importance c1 > c2 > c3 ... 
         Wj = {n -rj + 1} / {∑[ n - rk + 1], where k range is 1 to n}
+
+        :returns: no value
+        :rtype: none
         """
         n = len(self.df_original.columns) - 1
         r = np.arange(1, n+1, 1).tolist()
@@ -88,8 +123,12 @@ class MCDA:
 
     def set_weights_by_ranking_C(self):
         """
+        Set weights for MCDM problems and save it into attribute: weights.
         The criteria must be ordered by importance c1 > c2 > c3 ... 
         Wj = {1 / n} * {∑[ 1 / K ], where K range is j to n}
+
+        :returns: no value
+        :rtype: none
         """
         n = len(self.df_original.columns) - 1
         r = np.arange(1, n+1, 1)
@@ -106,8 +145,15 @@ class MCDA:
 
     def set_weights_by_ranking_B_POW(self, P=0):
         """
+        Set weights for MCDM problems and save it into attribute: weights.
         The criteria must be ordered by importance c1 > c2 > c3 ... 
-        Wj = {n -rj + 1}P / {∑[ n - rk + 1]P, where k range is 1 to n}
+        Wj = {n -rj + 1}^P / {∑[ n - rk + 1]^P, where k range is 1 to n}
+        
+        :param P: (default=0) 0 results in the same weight for all criteria,
+        :type P: int
+
+        :returns: no value
+        :rtype: none
         """
         n = len(self.df_original.columns) - 1
         r = np.arange(1, n+1, 1).tolist()
@@ -121,7 +167,15 @@ class MCDA:
         self.weights = W
 
     def set_weights_by_entropy(self, normalization_method_for_entropy=LinearSum_):
-        
+        """
+        Set weights by entropy for MCDM problems and save it into attribute: weights.
+
+        :param normalization_method_for_entropy: (default=LinearSum_) 0 results in the same weight for all criteria,
+        :type normalization_method_for_entropy: some value defined in NORMALIZATION_METHODS constant
+
+        :returns: no value
+        :rtype: none
+        """
         # Save current norm method
         current_norm_method = self.normalization_method
 
@@ -149,6 +203,22 @@ class MCDA:
         self.normalization_method = current_norm_method
 
     def set_weights_by_AHP(self, saaty_preference_matrix):
+        """
+        Set weights by AHP for MCDM problems and save it into attribute: weights.
+
+        e.g.
+                                              # C1   C2     C3   C4 
+        w_AHP = electre_i.set_weights_by_AHP([[  1,    4,    5,   7],   # C1
+                                              [1/4,    1,    3,   5],   # C2
+                                              [1/5,  1/3,    1,   3],   # C3
+                                              [1/7,  1/5,  1/3,   1]])  # C4
+    
+        :param saaty_preference_matrix: matrix of preferences of values in Saaty scale.
+        :type saaty_preference_matrix: list
+
+        :returns: no value
+        :rtype: none
+        """
         if self.__check_AHP_matrix(saaty_preference_matrix) is True:  
             saaty_preference_matrix = pd.DataFrame(saaty_preference_matrix)
             priority_vector = (saaty_preference_matrix / saaty_preference_matrix.sum(axis=0)).mean(axis=1)
@@ -164,6 +234,22 @@ class MCDA:
             return {"consistency": False, "lambda": lambda_max, "CIndex": CI, "CRatio": CR}
                   
     def set_signals(self, signals):
+        """
+        Set the target function of criteria for maximization or minimization and save it into attribute: signals.
+
+        e.g.
+            set_signals([-1, 1, 1, 1, 1])
+
+            or using contants MIN and MAX
+            
+            set_signals([MIN, MAX, MAX, MAX, MAX])
+
+        :param signals: 1 or MAX for maximization or MIN, -1 for minimization.
+        :type signals: list
+
+        :returns: no value
+        :rtype: none
+        """
         if self.__check_signals(signals) is True:
             self.signals = signals
         else:
@@ -353,13 +439,14 @@ class MCDA:
         weighted = self.df_normalized.iloc[:, 1:] * self.weights
         self.df_weighted = pd.DataFrame(self.df_original.iloc[:,0]).join(weighted)
 
-    def __check_weights(self, weights):
+    def __check_weights(self, weights, free=False):
         result = False
         if type(weights) == list:
             if len(self.df_original.columns.tolist()) - 1 == len(weights) \
-               and all(isinstance(n, float) for n in weights) \
+               and ((all(isinstance(n, float) for n in weights) \
                and all((n >= 0 and n <= 1) for n in weights) \
-               and round(sum(weights)) == 1:
+               and round(sum(weights)) == 1) \
+               or (free is True)):
                 result = True
         return result
 
@@ -391,18 +478,55 @@ class MCDA:
         return True
 
     def pretty_original(self, tablefmt='psql'):
+        """
+        Print a pretty table about specific attribute.
+
+        :param tablefmt: (default=psql) format of output 
+        :type: string constant: 'html', 'latex' or 'psql'
+
+        :returns: print
+        :rtype: string
+
+        """
         return tabulate(self.df_original, headers='keys', tablefmt=tablefmt)
 
     def pretty_normalized(self, tablefmt='psql'):
+        """
+        Print a pretty table about specific attribute.
+
+        :param tablefmt: (default=psql) format of output 
+        :type: string constant: 'html', 'latex' or 'psql'
+
+        :returns: print
+        :rtype: string
+
+        """
         return tabulate(self.df_normalized, headers='keys', tablefmt=tablefmt)
 
     def pretty_weighted(self, tablefmt='psql'):
+        """
+        Print a pretty table about specific attribute.
+
+        :param tablefmt: (default=psql) format of output 
+        :type: string constant: 'html', 'latex' or 'psql'
+
+        :returns: print
+        :rtype: string
+
+        """        
         return tabulate(self.df_weighted, headers='keys', tablefmt=tablefmt)
 
-    def pretty_Xis(self, tablefmt='psql'):
-        return tabulate(pd.DataFrame(self.df_pis, columns=['PIS']).join(pd.DataFrame(self.df_nis, columns=["NIS"])).T, headers='keys', tablefmt=tablefmt)
-    
     def pretty_decision(self, tablefmt='psql'):
+        """
+        Print a pretty table about specific attribute.
+
+        :param tablefmt: (default=psql) format of output 
+        :type: string constant: 'html', 'latex' or 'psql'
+
+        :returns: print
+        :rtype: string
+
+        """
         return tabulate(self.df_decision, headers='keys', tablefmt=tablefmt)
         
 
