@@ -1,4 +1,4 @@
-from mcda import MCDA, pd, np, Vector_
+from mcda import MCDA, pd, np, Vector_, tabulate
 
 class TOPSIS(MCDA):
     def __init__(self):
@@ -7,13 +7,21 @@ class TOPSIS(MCDA):
         self.df_closeness = 0
         super().__init__()        
     
-    def decide(self, normalization_method=Vector_):
+    def decide(self, normalization_method=Vector_):        
+        """
+        Method for decision making using TOPSIS. 
+
+        :param normalization_method: (default=Vector_) Must be defined when the problem data is different units,
+        :type normalization_method: some value defined in NORMALIZATION_METHODS constant
+
+        :returns: none value
+        :rtype: none
+        """   
         self._MCDA__set_normalization_method(normalization_method)      
         self._MCDA__normalize(True)
         self._MCDA__weighting_from_normalized()
         self.__xis()
         self.__topsis()
-        return "topsis"
          
     def __xis(self):
         pis = pd.DataFrame(self.df_weighted.iloc[:, 1:] * self.signals).max(axis=0) * self.signals
@@ -30,3 +38,16 @@ class TOPSIS(MCDA):
         df_ranking["rank"] = i
 
         self.df_decision = df_ranking.sort_index()
+
+    def pretty_Xis(self, tablefmt='psql'):
+        """
+        Print a pretty table about positive and negative ideal solutions attributes (df_pis and df_nis).
+
+        :param tablefmt: (default=psql) format of output 
+        :type: string constant: 'html', 'latex' or 'psql'
+
+        :returns: print
+        :rtype: string
+
+        """        
+        return tabulate(pd.DataFrame(self.df_pis, columns=['PIS']).join(pd.DataFrame(self.df_nis, columns=["NIS"])).T, headers='keys', tablefmt=tablefmt)
