@@ -5,12 +5,23 @@ class WASPAS(MCDA):
         super().__init__()        
     
     def decide(self, lambda_=0.5, normalization_method=None):
+        """
+        Method for decision making using WASPAS. 
+
+        :param lambda_: (default=0.5) Must be defined for tunning purpose,
+        :type lambda_: float
+
+        :param normalization_method: (default=None) Must be defined when the problem data is different units,
+        :type normalization_method: some value defined in NORMALIZATION_METHODS constant
+
+        :returns: none value
+        :rtype: none
+        """   
         if self.__check_lambda(lambda_) is True:
             self._MCDA__set_normalization_method(normalization_method)
             self._MCDA__normalize()
             self._MCDA__weighting_from_normalized()
             self.__waspas(lambda_)
-            return "waspas"
 
     def __waspas(self, lambda_):
         w_df = pd.DataFrame(self.df_weighted.iloc[:, 1:])       
