@@ -5,11 +5,19 @@ class WPM(MCDA):
         super().__init__()        
     
     def decide(self, normalization_method=None):  
+        """
+        Method for decision making using WPM. 
+
+        :param normalization_method: (default=None) Must be defined when the problem data is different units,
+        :type normalization_method: some value defined in NORMALIZATION_METHODS constant
+
+        :returns: none value
+        :rtype: none
+        """   
         self._MCDA__set_normalization_method(normalization_method)
         self._MCDA__normalize()
         self._MCDA__weighting_from_normalized()
         self.__wpm()
-        return "wsm"
 
     def __wpm(self):
         wpm = pd.DataFrame(self.df_weighted.iloc[:, 1:])
