@@ -5,12 +5,19 @@ class WSM(MCDA):
         super().__init__()        
     
     def decide(self, normalization_method=None):  
+        """
+        Method for decision making using WSM/SAW. 
+
+        :param normalization_method: (default=None) Must be defined when the problem data is different units,
+        :type normalization_method: some value defined in NORMALIZATION_METHODS constant
+
+        :returns: none value
+        :rtype: none
+        """   
         self._MCDA__set_normalization_method(normalization_method)
         self._MCDA__normalize()
         self._MCDA__weighting_from_normalized()
         self.__wsm()
-        return "wsm"
-
 
     def __wsm(self):
         wsm = pd.DataFrame(self.df_weighted.iloc[:, 1:])
